==> ini_config_parser-0.1.tar.gz: ini_config_parser-0.1/setup.py <==
from distutils.core import setup

setup(
    name="ini_config_parser",  # How you named your package folder (MyLib)
    packages=["ini_config_parser"],  # Chose the same as "name"
    version="0.1",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Provides convenient interface for easily managing multiple enviroments (ex: test, prod) just from one config.ini",  # Give a short description about your library
    author="depozzyx",  # Type in your name
    author_email="2015hhh333@gmail.com",  # Type in your E-Mail
    url="https://github.com/depozzyx/ini_config_parser",  # Provide either the link to your github or to your website
    download_url="https://github.com/depozzyx/ini_config_parser/archive/refs/tags/release.tar.gz",  # I explain this later on
    keywords=["Ini", "Parser", "Config"],  # Keywords that define your package best
    install_requires=[],  # I get to this in a second
    classifiers=[
        "Development Status :: 4 - Beta",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
    ],
)

==> ini_config_parser-0.2.tar.gz: ini_config_parser-0.2/setup.py <==
from distutils.core import setup

setup(
    name="ini_config_parser",  # How you named your package folder (MyLib)
    packages=["ini_config_parser"],  # Chose the same as "name"
    version="0.2",  # Start with a small number and increase it with every change you make
    license="MIT",  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description="Provides convenient interface for easily managing multiple enviroments (ex: test, prod) just from one config.ini",  # Give a short description about your library
    author="depozzyx",  # Type in your name
    author_email="2015hhh333@gmail.com",  # Type in your E-Mail
    url="https://github.com/depozzyx/ini_config_parser",  # Provide either the link to your github or to your website
    download_url="https://github.com/depozzyx/ini_config_parser/archive/refs/tags/release-0.2.tar.gz",  # I explain this later on
    keywords=["Ini", "Parser", "Config"],  # Keywords that define your package best
    install_requires=[],  # I get to this in a second
    classifiers=[
        "Development Status :: 4 - Beta",  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Intended Audience :: Developers",  # Define that your audience are developers
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",  # Again, pick a license
        "Programming Language :: Python :: 3",  # Specify which pyhton versions that you want to support
    ],
)
